Polynomial

Struct Polynomial 

pub struct Polynomial<const N: usize, E: FieldScalar> { /* private fields */ }
Univariate negacyclic polynomial ring (modulus X^N + 1). Accelerated with number theoretic transforms and lazy moves between coefficient and eval representation.

Implementations

Source

impl<const N: usize, E: FieldScalar> Polynomial<N, E>

pub fn to_eval_form(&mut self)

pub fn to_coef_form(&mut self)

pub fn into_eval_form(self) -> Self

pub fn into_coef_form(self) -> Self

pub fn evaluate(&self, x: E) -> E

Evaluate the polynomial at a point.

pub fn batch_mul(self, rhs: Vector<Self>) -> Vector<Self>

Multiply a single polynomial by a vector of polynomials.

pub fn split_root(root: E) -> Result<Self>

Retrieve the product of monomial factors split by the provided root of unity.

pub fn coefs_slice_mut(&mut self) -> &mut [E; N]

pub fn coefs(&self) -> impl Iterator<Item = E> + ExactSizeIterator + Clone

Get an iterator over all coefficients.

TODO: coefs_nonzero ?

pub fn coefs_mut(&mut self) -> impl Iterator<Item = &mut E> + ExactSizeIterator

Get a mutable iterator over all coefficients.

pub fn norm_l2(&self) -> f64

The l2 norm of the polynomial. Represents the magnitude.

The distance of each coefficient from zero is squared and then summed. The square root of the sum is returned.

sqrt(x[0]^2 + x[1]^2 + x[2]^2 ...)

pub fn sample_gaussian<R: Rng>(sigma: f64, rng: &mut R) -> Self

Sample a polynomial with coefficients in a gaussian distribution with standard deviation sigma.

Internally uses a statically cached distribution table for each stddev initialized on first call.